@@ -17,6 +17,7 @@ import io.fabric8.kubernetes.api.model.HasMetadata;
 import io.fabric8.kubernetes.api.model.KubernetesResourceList;
 import io.fabric8.kubernetes.api.model.ServiceAccountBuilder;
 import io.fabric8.kubernetes.client.KubernetesClient;
+import io.fabric8.kubernetes.client.KubernetesClientException;
 import io.fabric8.kubernetes.client.dsl.MixedOperation;
 import io.fabric8.kubernetes.client.dsl.Resource;
 import java.util.Arrays;
@@ -85,9 +86,6 @@ public abstract class AbstractWorkspaceServiceAccount<
    * Make sure that workspace service account exists and has `view` and `exec` role bindings, as
    * well as create workspace-view and exec roles in namespace scope
    *
-   * <p>Do NOT make any changes to the service account if it already exists in the namespace to
-   * preserve its configuration done by someone else.
-   *
    * @throws InfrastructureException when any exception occurred
    */
   public void prepare() throws InfrastructureException {
@@ -95,9 +93,9 @@ public abstract class AbstractWorkspaceServiceAccount<
     if (k8sClient.serviceAccounts().inNamespace(namespace).withName(serviceAccountName).get()
         == null) {
       createWorkspaceServiceAccount(k8sClient);
-      createImplicitRolesWithBindings(k8sClient);
-      createExplicitClusterRoleBindings(k8sClient);
     }
+    ensureImplicitRolesWithBindings(k8sClient);
+    ensureExplicitClusterRoleBindings(k8sClient);
   }
 
   /**
@@ -106,9 +104,9 @@ public abstract class AbstractWorkspaceServiceAccount<
    *
    * <p>creates {@code <sa>-exec} and {@code <sa>-view}
    */
-  private void createImplicitRolesWithBindings(Client k8sClient) {
+  private void ensureImplicitRolesWithBindings(Client k8sClient) {
     // exec role
-    createRoleWithBinding(
+    ensureRoleWithBinding(
         k8sClient,
         EXEC_ROLE_NAME,
         singletonList("pods/exec"),
@@ -117,7 +115,7 @@ public abstract class AbstractWorkspaceServiceAccount<
         serviceAccountName + "-exec");
 
     // view role
-    createRoleWithBinding(
+    ensureRoleWithBinding(
         k8sClient,
         VIEW_ROLE_NAME,
         Arrays.asList("pods", "services"),
@@ -126,23 +124,35 @@ public abstract class AbstractWorkspaceServiceAccount<
         serviceAccountName + "-view");
 
     // metrics role
-    createRoleWithBinding(
-        k8sClient,
-        METRICS_ROLE_NAME,
-        Arrays.asList("pods", "nodes"),
-        singletonList("metrics.k8s.io"),
-        Arrays.asList("list", "get", "watch"),
-        serviceAccountName + "-metrics");
+    try {
+      if (k8sClient.supportsApiPath("/apis/metrics.k8s.io")) {
+        ensureRoleWithBinding(
+            k8sClient,
+            METRICS_ROLE_NAME,
+            Arrays.asList("pods", "nodes"),
+            singletonList("metrics.k8s.io"),
+            Arrays.asList("list", "get", "watch"),
+            serviceAccountName + "-metrics");
+      }
+    } catch (KubernetesClientException e) {
+      // workaround to unblock workspace start if no permissions for metrics
+      if (e.getCode() == 403) {
+        LOG.warn(
+            "Unable to add metrics roles due to insufficient permissions. Workspace metrics will be disabled.");
+      } else {
+        throw e;
+      }
+    }
   }
 
-  private void createRoleWithBinding(
+  private void ensureRoleWithBinding(
       Client k8sClient,
       String roleName,
       List<String> resources,
       List<String> apiGroups,
       List<String> verbs,
       String bindingName) {
-    createRole(k8sClient, roleName, resources, apiGroups, verbs);
+    ensureRole(k8sClient, roleName, resources, apiGroups, verbs);
     //noinspection unchecked
     roleBindings
         .apply(k8sClient)
@@ -158,7 +168,7 @@ public abstract class AbstractWorkspaceServiceAccount<
    *     boolean, String, String, KubernetesClientFactory, CheServerKubernetesClientFactory,
    *     UserManager, PreferenceManager, KubernetesSharedPool)
    */
-  private void createExplicitClusterRoleBindings(Client k8sClient) {
+  private void ensureExplicitClusterRoleBindings(Client k8sClient) {
     // If the user specified an additional cluster roles for the workspace,
     // create a role binding for them too
     int idx = 0;
@@ -212,16 +222,17 @@ public abstract class AbstractWorkspaceServiceAccount<
                 .build());
   }
 
-  private void createRole(
+  private void ensureRole(
       Client k8sClient,
       String name,
       List<String> resources,
       List<String> apiGroups,
       List<String> verbs) {
-    if (roles.apply(k8sClient).inNamespace(namespace).withName(name).get() == null) {
-      R role = buildRole(name, resources, apiGroups, verbs);
-      roles.apply(k8sClient).inNamespace(namespace).create(role);
-    }
+    //noinspection unchecked
+    roles
+        .apply(k8sClient)
+        .inNamespace(namespace)
+        .createOrReplace(buildRole(name, resources, apiGroups, verbs));
   }
 
   public interface ClientFactory<C extends KubernetesClient> {
