@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -11,7 +11,10 @@
  */
 package org.eclipse.che.workspace.infrastructure.kubernetes.server.external;
 
+import javax.inject.Inject;
+import javax.inject.Named;
 import javax.inject.Singleton;
+import org.eclipse.che.commons.annotation.Nullable;
 
 /**
  * This Factory provides {@link GatewayRouteConfigGenerator} instances, so implementation using
@@ -20,7 +23,15 @@ import javax.inject.Singleton;
 @Singleton
 public class GatewayRouteConfigGeneratorFactory {
 
+  private final String clusterDomain;
+
+  @Inject
+  public GatewayRouteConfigGeneratorFactory(
+      @Nullable @Named("che.infra.kubernetes.cluster_domain") String clusterDomain) {
+    this.clusterDomain = clusterDomain;
+  }
+
   public GatewayRouteConfigGenerator create() {
-    return new TraefikGatewayRouteConfigGenerator();
+    return new TraefikGatewayRouteConfigGenerator(clusterDomain);
   }
 }
