@@ -97,7 +97,6 @@ import org.testng.collections.Sets;
  *
  * @author Sergii Leshchenko
  */
-@Test
 @Listeners(MockitoTestNGListener.class)
 public class KubernetesNamespaceFactoryTest {
 
@@ -622,6 +621,7 @@ public class KubernetesNamespaceFactoryTest {
     when(toReturnNamespace.getWorkspaceId()).thenReturn("workspace123");
     when(toReturnNamespace.getName()).thenReturn("workspace123");
     doReturn(toReturnNamespace).when(namespaceFactory).doCreateNamespaceAccess(any(), any());
+    when(k8sClient.supportsApiPath(eq("/apis/metrics.k8s.io"))).thenReturn(true);
     when(clientFactory.create(any())).thenReturn(k8sClient);
 
     // pre-create the cluster roles
@@ -652,9 +652,8 @@ public class KubernetesNamespaceFactoryTest {
 
     RoleList roles = k8sClient.rbac().roles().inNamespace("workspace123").list();
     assertEquals(
-        Sets.newHashSet("workspace-view", "workspace-metrics", "exec"),
-        roles.getItems().stream().map(r -> r.getMetadata().getName()).collect(Collectors.toSet()));
-
+        roles.getItems().stream().map(r -> r.getMetadata().getName()).collect(Collectors.toSet()),
+        Sets.newHashSet("workspace-view", "workspace-metrics", "exec"));
     RoleBindingList bindings = k8sClient.rbac().roleBindings().inNamespace("workspace123").list();
     assertEquals(
         bindings
@@ -692,6 +691,7 @@ public class KubernetesNamespaceFactoryTest {
     when(toReturnNamespace.getWorkspaceId()).thenReturn("workspace123");
     when(toReturnNamespace.getName()).thenReturn("workspace123");
     doReturn(toReturnNamespace).when(namespaceFactory).doCreateNamespaceAccess(any(), any());
+    when(k8sClient.supportsApiPath(eq("/apis/metrics.k8s.io"))).thenReturn(true);
     when(clientFactory.create(any())).thenReturn(k8sClient);
 
     // when
@@ -708,8 +708,8 @@ public class KubernetesNamespaceFactoryTest {
 
     RoleList roles = k8sClient.rbac().roles().inNamespace("workspace123").list();
     assertEquals(
-        Sets.newHashSet("workspace-view", "workspace-metrics", "exec"),
-        roles.getItems().stream().map(r -> r.getMetadata().getName()).collect(Collectors.toSet()));
+        roles.getItems().stream().map(r -> r.getMetadata().getName()).collect(Collectors.toSet()),
+        Sets.newHashSet("workspace-view", "workspace-metrics", "exec"));
     Role role1 = roles.getItems().get(0);
     Role role2 = roles.getItems().get(1);
 
@@ -720,12 +720,12 @@ public class KubernetesNamespaceFactoryTest {
 
     RoleBindingList bindings = k8sClient.rbac().roleBindings().inNamespace("workspace123").list();
     assertEquals(
-        Sets.newHashSet("serviceAccount-metrics", "serviceAccount-view", "serviceAccount-exec"),
         bindings
             .getItems()
             .stream()
             .map(r -> r.getMetadata().getName())
-            .collect(Collectors.toSet()));
+            .collect(Collectors.toSet()),
+        Sets.newHashSet("serviceAccount-metrics", "serviceAccount-view", "serviceAccount-exec"));
   }
 
   @Test
@@ -787,8 +787,6 @@ public class KubernetesNamespaceFactoryTest {
             preferenceManager,
             pool);
 
-    when(namespaceResource.get()).thenReturn(null);
-
     WorkspaceImpl workspace =
         new WorkspaceImplBuilder().setId("workspace123").setAttributes(emptyMap()).build();
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
