@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -20,6 +20,9 @@ import java.util.Optional;
  */
 public interface RemoteFactoryUrl {
 
+  /** Provider name for given URL. */
+  String getProviderName();
+
   /**
    * List of possible filenames and raw locations of devfile.
    *
@@ -33,6 +36,9 @@ public interface RemoteFactoryUrl {
   /** Remote hostname */
   String getHostName();
 
+  /** Remote branch */
+  String getBranch();
+
   /** Describes devfile location, including filename if any. */
   interface DevfileLocation {
     Optional<String> filename();
