@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -282,11 +282,6 @@ public class WorkspaceRuntimes {
     return infrastructure.evaluateInfraNamespace(resolutionCtx);
   }
 
-  public String evalLegacyInfrastructureNamespace(NamespaceResolutionContext resolutionContext)
-      throws InfrastructureException {
-    return infrastructure.evaluateLegacyInfraNamespace(resolutionContext);
-  }
-
   /**
    * This method just passes on the question down to the underlying infrastructure.
    *
