@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -30,7 +30,6 @@ import static org.eclipse.che.api.workspace.shared.Constants.CHE_WORKSPACE_STORA
 import static org.eclipse.che.api.workspace.shared.Constants.CHE_WORKSPACE_STORAGE_PREFERRED_TYPE;
 import static org.eclipse.che.api.workspace.shared.Constants.DEBUG_WORKSPACE_START;
 import static org.eclipse.che.api.workspace.shared.Constants.DEBUG_WORKSPACE_START_LOG_LIMIT_BYTES;
-import static org.eclipse.che.api.workspace.shared.Constants.WORKSPACE_INFRASTRUCTURE_NAMESPACE_ATTRIBUTE;
 
 import com.google.common.base.Joiner;
 import com.google.common.collect.ImmutableMap;
@@ -188,14 +187,6 @@ public class WorkspaceService extends Service {
               examples = @Example({@ExampleProperty("attrName:value-with:colon")}))
           @QueryParam("attribute")
           List<String> attrsList,
-      @ApiParam(
-              value =
-                  "The target infrastructure namespace (Kubernetes namespace or OpenShift"
-                      + " project) where the workspace should be deployed to when started. This"
-                      + " parameter is optional. The workspace creation will fail if the Che server"
-                      + " is configured to not allow deploying into that infrastructure namespace.")
-          @QueryParam("infrastructure-namespace")
-          String infrastructureNamespace,
       @ApiParam(
               "If true then the workspace will be immediately "
                   + "started after it is successfully created")
@@ -212,9 +203,6 @@ public class WorkspaceService extends Service {
     if (namespace == null) {
       namespace = EnvironmentContext.getCurrent().getSubject().getUserName();
     }
-    if (!isNullOrEmpty(infrastructureNamespace)) {
-      attributes.put(WORKSPACE_INFRASTRUCTURE_NAMESPACE_ATTRIBUTE, infrastructureNamespace);
-    }
     WorkspaceImpl workspace;
     try {
       workspace =
